@@ -2,6 +2,7 @@ import json
 
 from awesomeTaskPy.log.loger import loger
 from awesomeTaskPy.queue.queue import queue
+from awesomeTaskPy.context.systemEventRegister import systemEventRegister
 import sys
 contextObj=None
 class Singleton(object):
@@ -46,6 +47,10 @@ def initContext():
         if not isinstance(taskInfo, dict):
             taskInfo = json.loads(taskInfo)
         contextObj = context(taskInfo)
+        #עϵͳ¼  ע¼òҪĴ
+        # ¼ĵڽܽڵ㴫߳
+        # ڴ¼ִ֮ǰȡڵ㷵ص
+        systemEventRegister.register()
     else:
         contextObj=context(None)
         raise Exception("context failed find taskInfo from command")
