@@ -4,7 +4,7 @@ class event:
     def register(name,fun):
         if name not in eventMap:
             eventMap[name] = []
-        list(eventMap[name]).append(fun)
+        eventMap[name].append(fun)
     @staticmethod
     def dispatch(event,params):
         if event in eventMap.keys():
