@@ -26,9 +26,11 @@ class loger():
     __SEPARATOR = "<=========>"
     # ÷ֵ·
     __realResultPath = None
+    __queue = None
 
     def __init__(self, taskId):
         self.__taskId = taskId
+        self.num=1
         self.__logPath = sys.path[0] + "/runtime" + "/" + taskId + "/"
         mkdir(self.__logPath)
         self.__tmpPath = self.__logPath + "tmp.log"
@@ -36,11 +38,15 @@ class loger():
         self.__reaLogPath = self.__logPath + "runtime.log"
         self.__reaLogPath = self.__logPath + "input.log"
         self.__realResultPath = self.__logPath + "result.log"
+        self.__outputResultPath =self.__logPath +"childrenTask/"
         # ϴεõĽ ´˽ ӽڵشĽڵ
         if os.path.isfile(self.__realResultPath):
             os.unlink(self.__realResultPath)
         self.flushTmpLog()
-
+    def setQueue(self,queue):
+        self.__queue = queue
+    def writeToServer(self,msg):
+        self.__queue.send(msg)
     # ʱ д־
     def flushTmpLog(self):
         if os.path.isfile(self.__tmpPath):
@@ -52,14 +58,28 @@ class loger():
 
     # д־
     def write(self, content):
-        with open(self.__tmpPath, 'a') as f:
-            f.write(content + "\n")
+        data={
+            "content":content,
+            "event":"ON_TASK_NODE_LOG",
+            "taskId":self.__taskId
+        }
+        self.writeToServer(data)
         return self
 
     # ֵд뵽ļ
     def writeRes(self, content):
-        with open(self.__realResultPath, "w") as f:
+        data = {
+            "content": content,
+            "event": "ON_TASK_NODE_RESULT",
+            "taskId": self.__taskId
+        }
+        self.writeToServer(data)
+        return self
+    # ִеĹɵĲ 
+    def writeOutputAndFork(self, content):
+        with open(self.__outputResultPath+str(self.num)+".log", "w") as f:
             f.write(json.dumps(content))
+        self.num=self.num+1
         return self
 
     @staticmethod
