@@ -5,6 +5,7 @@ import json
 import awesomeTaskPy
 from awesomeTaskPy.context.context import context
 from awesomeTaskPy.context.event import event
+from awesomeTaskPy.task.childrenTask import childrenTask
 import time
 import sys
 import traceback
@@ -30,6 +31,7 @@ class baseTask():
     def __init__(self, taskInfo, modulePath):
         def ON_CHILDREN_TASK_FINISHED_HANDLER(params):
             taskExecuteResult[params['taskId']]=params
+            event.dispatch(params['taskId'],params)
         event.register("ON_CHILDREN_TASK_FINISHED",ON_CHILDREN_TASK_FINISHED_HANDLER)
         self.__taskInfo = taskInfo
         self.__modulePath = modulePath
@@ -88,13 +90,12 @@ class baseTask():
             "fun":fun.__name__,
             "input":args,
             "project_name":contextObj.getTaskInfo()["project_name"],
-            "pTaskId":contextObj.getTaskInfo()['uniqueTaskId'],
             "taskId":childrenTaskId
         }
         taskIds.append(childrenTaskId)
         contextObj.getQueue().send(RPC)
         contextObj.getQueue().startRecv()
-        return childrenTaskId
+        return childrenTask(RPC)
     ##获取任务执行的结果
     ##由于是异步执行 这里会等待执行结果并且返回
     @staticmethod
